.. _Api:

API Reference
=============

malaya
------

.. automodule:: malaya
    :members:

malaya.augmentation
---------------------

.. automodule:: malaya.augmentation
    :members:

malaya.cluster
-----------------

.. automodule:: malaya.cluster
    :members:

malaya.dependency
------------------

.. automodule:: malaya.dependency
    :members:

malaya.emotion
-----------------

.. automodule:: malaya.emotion
    :members:

malaya.entity
---------------

.. automodule:: malaya.entity
    :members:

malaya.generator
-------------------------

.. automodule:: malaya.generator
    :members:

malaya.language_detection
-------------------------

.. automodule:: malaya.language_detection
    :members:

malaya.lexicon
-------------------------

.. automodule:: malaya.lexicon
    :members:

malaya.normalize
-------------------------

.. automodule:: malaya.normalize
    :members:

.. autoclass:: malaya.normalize.NORMALIZER()
    :members:

malaya.num2word
-----------------

.. automodule:: malaya.num2word
    :members:

malaya.pos
-----------------

.. automodule:: malaya.pos
    :members:

malaya.preprocessing
----------------------

.. automodule:: malaya.preprocessing
    :members:

.. autoclass:: malaya.preprocessing.SocialTokenizer()
    :members:

malaya.relevancy
------------------

.. automodule:: malaya.relevancy
    :members:

malaya.sentiment
-----------------

.. automodule:: malaya.sentiment
    :members:

malaya.spell
-----------------

.. automodule:: malaya.spell
    :members:

.. autoclass:: malaya.spell._TransformerCorrector()
    :members:

.. autoclass:: malaya.spell._SpellCorrector()
    :members:

.. autoclass:: malaya.spell._SymspellCorrector()
    :members:

malaya.stack
-----------------

.. automodule:: malaya.stack
    :members:

malaya.stem
-----------------

.. automodule:: malaya.stem
    :members:

.. autoclass:: malaya.stem.DEEP_STEMMER()
    :members:

malaya.subjective
-----------------

.. automodule:: malaya.subjective
    :members:

malaya.summarize
---------------------

.. automodule:: malaya.summarize
    :members:

.. autoclass:: malaya.summarize._DEEP_SUMMARIZER()
    :members:

.. autoclass:: malaya.summarize._DEEP_SKIPTHOUGHT()
    :members:

malaya.similarity
-------------------------

.. automodule:: malaya.similarity
    :members:

.. autoclass:: malaya.similarity._VECTORIZER_SIMILARITY()
    :members:

.. autoclass:: malaya.similarity._DOC2VEC_SIMILARITY()
    :members:

malaya.topic_model
-----------------------

.. automodule:: malaya.topic_model
    :members:

.. autoclass:: malaya.topic_model._TOPIC()
    :members:

.. autoclass:: malaya.topic_model._DEEP_TOPIC()
    :members:

malaya.toxic
-------------------------

.. automodule:: malaya.toxic
    :members:

malaya.transformer
-------------------------

.. automodule:: malaya.transformer
    :members:

malaya.wordvector
-------------------------

.. automodule:: malaya.wordvector
    :members:

.. autoclass:: malaya.wordvector._wordvector()
    :members:

malaya.transformers.albert
-----------------------------

.. automodule:: malaya.transformers.albert
    :members:

.. autoclass:: malaya.transformers.albert.Model()
    :members:

malaya.transformers.alxlnet
-----------------------------

.. automodule:: malaya.transformers.alxlnet
    :members:

.. autoclass:: malaya.transformers.alxlnet.Model()
    :members:

malaya.transformers.bert
-----------------------------

.. automodule:: malaya.transformers.bert
    :members:

.. autoclass:: malaya.transformers.bert.Model()
    :members:

malaya.transformers.electra
-----------------------------

.. automodule:: malaya.transformers.electra
    :members:

.. autoclass:: malaya.transformers.electra.Model()
    :members:

malaya.transformers.gpt2
-----------------------------

.. automodule:: malaya.transformers.gpt2
    :members:

.. autoclass:: malaya.transformers.gpt2.Model()
    :members:

malaya.transformers.xlnet
-----------------------------

.. automodule:: malaya.transformers.xlnet
    :members:

.. autoclass:: malaya.transformers.xlnet.Model()
    :members:

malaya.model.tf
----------------------------------

.. autoclass:: malaya.model.tf.DEEP_LANG()
    :members:

malaya.model.ml
----------------------------------

.. autoclass:: malaya.model.ml.MULTICLASS_BAYES()
    :members:

.. autoclass:: malaya.model.ml.BINARY_BAYES()
    :members:

.. autoclass:: malaya.model.ml.MULTILABEL_BAYES()
    :members:

malaya.model.bert
----------------------------------

.. autoclass:: malaya.model.bert.BINARY_BERT()
    :members:

.. autoclass:: malaya.model.bert.MULTICLASS_BERT()
    :members:

.. autoclass:: malaya.model.bert.SIGMOID_BERT()
    :members:

.. autoclass:: malaya.model.bert.SIAMESE_BERT()
    :members:

.. autoclass:: malaya.model.bert.TAGGING_BERT()
    :members:

.. autoclass:: malaya.model.bert.DEPENDENCY_BERT()
    :members:

malaya.model.xlnet
----------------------------------

.. autoclass:: malaya.model.xlnet.BINARY_XLNET()
    :members:

.. autoclass:: malaya.model.xlnet.MULTICLASS_XLNET()
    :members:

.. autoclass:: malaya.model.xlnet.SIGMOID_XLNET()
    :members:

.. autoclass:: malaya.model.xlnet.SIAMESE_XLNET()
    :members:

.. autoclass:: malaya.model.xlnet.TAGGING_XLNET()
    :members:

.. autoclass:: malaya.model.xlnet.DEPENDENCY_XLNET()
    :members:
